/****************************************************************************
** Meta object code from reading C++ file 'partmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kparts-6.26.0/src/partmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'partmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KParts11PartManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KParts::PartManager::qt_create_metaobjectdata<qt_meta_tag_ZN6KParts11PartManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KParts::PartManager",
        "partAdded",
        "",
        "KParts::Part*",
        "part",
        "partRemoved",
        "activePartChanged",
        "newPart",
        "slotObjectDestroyed",
        "slotWidgetDestroyed",
        "slotManagedTopLevelWidgetDestroyed",
        "selectionPolicy",
        "SelectionPolicy",
        "allowNestedParts",
        "ignoreScrollBars",
        "Direct",
        "TriState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'partAdded'
        QtMocHelpers::SignalData<void(KParts::Part *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'partRemoved'
        QtMocHelpers::SignalData<void(KParts::Part *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'activePartChanged'
        QtMocHelpers::SignalData<void(KParts::Part *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Slot 'slotObjectDestroyed'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotWidgetDestroyed'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotManagedTopLevelWidgetDestroyed'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'selectionPolicy'
        QtMocHelpers::PropertyData<enum SelectionPolicy>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'allowNestedParts'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'ignoreScrollBars'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SelectionPolicy'
        QtMocHelpers::EnumData<enum SelectionPolicy>(12, 12, QMC::EnumFlags{}).add({
            {   15, SelectionPolicy::Direct },
            {   16, SelectionPolicy::TriState },
        }),
    };
    return QtMocHelpers::metaObjectData<PartManager, qt_meta_tag_ZN6KParts11PartManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KParts::PartManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts11PartManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts11PartManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KParts11PartManagerE_t>.metaTypes,
    nullptr
} };

void KParts::PartManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PartManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->partAdded((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 1: _t->partRemoved((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 2: _t->activePartChanged((*reinterpret_cast<std::add_pointer_t<KParts::Part*>>(_a[1]))); break;
        case 3: _t->slotObjectDestroyed(); break;
        case 4: _t->slotWidgetDestroyed(); break;
        case 5: _t->slotManagedTopLevelWidgetDestroyed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PartManager::*)(KParts::Part * )>(_a, &PartManager::partAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartManager::*)(KParts::Part * )>(_a, &PartManager::partRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PartManager::*)(KParts::Part * )>(_a, &PartManager::activePartChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum SelectionPolicy*>(_v) = _t->selectionPolicy(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->allowNestedParts(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->ignoreScrollBars(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSelectionPolicy(*reinterpret_cast<enum SelectionPolicy*>(_v)); break;
        case 1: _t->setAllowNestedParts(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setIgnoreScrollBars(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KParts::PartManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KParts::PartManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts11PartManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KParts::PartManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void KParts::PartManager::partAdded(KParts::Part * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KParts::PartManager::partRemoved(KParts::Part * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KParts::PartManager::activePartChanged(KParts::Part * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
