/****************************************************************************
** Meta object code from reading C++ file 'partloader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kparts-6.26.0/src/partloader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'partloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KPartsE_t {};
} // unnamed namespace

template <> constexpr inline auto KParts::qt_create_metaobjectdata<qt_meta_tag_ZN6KPartsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KParts",
        "PartCapability",
        "ReadOnly",
        "ReadWrite",
        "BrowserView",
        "PartCapabilities"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PartCapability'
        QtMocHelpers::EnumData<PartCapability>(1, 1, QMC::EnumIsScoped).add({
            {    2, PartCapability::ReadOnly },
            {    3, PartCapability::ReadWrite },
            {    4, PartCapability::BrowserView },
        }),
        // flag 'PartCapabilities'
        QtMocHelpers::EnumData<PartCapabilities>(5, 1, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {    2, PartCapability::ReadOnly },
            {    3, PartCapability::ReadWrite },
            {    4, PartCapability::BrowserView },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN6KPartsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN6KPartsE =
    KParts::qt_create_metaobjectdata<qt_meta_tag_ZN6KPartsE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN6KPartsE =
    qt_staticMetaObjectContent_ZN6KPartsE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN6KPartsE =
    qt_staticMetaObjectContent_ZN6KPartsE.relocatingData;

Q_CONSTINIT const QMetaObject KParts::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN6KPartsE.stringdata,
    qt_staticMetaObjectStaticContent_ZN6KPartsE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN6KPartsE.metaTypes,
    nullptr
} };

QT_WARNING_POP
