/****************************************************************************
** Meta object code from reading C++ file 'navigationextension.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kparts-6.26.0/src/navigationextension.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'navigationextension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KParts19NavigationExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto KParts::NavigationExtension::qt_create_metaobjectdata<qt_meta_tag_ZN6KParts19NavigationExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KParts::NavigationExtension",
        "enableAction",
        "",
        "const char*",
        "name",
        "enabled",
        "setActionText",
        "text",
        "openUrlRequest",
        "QUrl",
        "url",
        "KParts::OpenUrlArguments",
        "arguments",
        "openUrlRequestDelayed",
        "openUrlNotify",
        "setLocationBarUrl",
        "setIconUrl",
        "createNewWindow",
        "loadingProgress",
        "percent",
        "speedProgress",
        "bytesPerSecond",
        "infoMessage",
        "popupMenu",
        "QPoint",
        "global",
        "KFileItemList",
        "items",
        "KParts::NavigationExtension::PopupFlags",
        "flags",
        "KParts::NavigationExtension::ActionGroupMap",
        "actionGroups",
        "mode_t",
        "mode",
        "selectionInfo",
        "mouseOverInfo",
        "KFileItem",
        "item",
        "addWebSideBar",
        "moveTopLevelWidget",
        "x",
        "y",
        "resizeTopLevelWidget",
        "w",
        "h",
        "requestFocus",
        "KParts::ReadOnlyPart*",
        "part",
        "setPageSecurity",
        "itemsRemoved",
        "slotOpenUrlRequest",
        "slotEmitOpenUrlRequestDelayed",
        "slotEnableAction",
        "slotSetActionText",
        "urlDropHandling"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enableAction'
        QtMocHelpers::SignalData<void(const char *, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'setActionText'
        QtMocHelpers::SignalData<void(const char *, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'openUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'openUrlRequest'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'openUrlRequestDelayed'
        QtMocHelpers::SignalData<void(const QUrl &, const KParts::OpenUrlArguments &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'openUrlNotify'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setLocationBarUrl'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'setIconUrl'
        QtMocHelpers::SignalData<void(const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'createNewWindow'
        QtMocHelpers::SignalData<void(const QUrl &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'loadingProgress'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'speedProgress'
        QtMocHelpers::SignalData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Signal 'infoMessage'
        QtMocHelpers::SignalData<void(const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 26, 27 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 28, 29 },
            { 0x80000000 | 30, 31 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &, KParts::NavigationExtension::PopupFlags)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 26, 27 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 28, 29 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &, const KParts::OpenUrlArguments &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 26, 27 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const KFileItemList &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, KParts::NavigationExtension::PopupFlags, const KParts::NavigationExtension::ActionGroupMap &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 32, 33 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 28, 29 }, { 0x80000000 | 30, 31 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &, KParts::NavigationExtension::PopupFlags)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 32, 33 }, { 0x80000000 | 11, 12 },
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t, const KParts::OpenUrlArguments &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 32, 33 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &, mode_t)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 32, 33 },
        }}),
        // Signal 'popupMenu'
        QtMocHelpers::SignalData<void(const QPoint &, const QUrl &)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'selectionInfo'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'mouseOverInfo'
        QtMocHelpers::SignalData<void(const KFileItem &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Signal 'addWebSideBar'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'moveTopLevelWidget'
        QtMocHelpers::SignalData<void(int, int)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 }, { QMetaType::Int, 41 },
        }}),
        // Signal 'resizeTopLevelWidget'
        QtMocHelpers::SignalData<void(int, int)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 }, { QMetaType::Int, 44 },
        }}),
        // Signal 'requestFocus'
        QtMocHelpers::SignalData<void(KParts::ReadOnlyPart *)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Signal 'setPageSecurity'
        QtMocHelpers::SignalData<void(int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'itemsRemoved'
        QtMocHelpers::SignalData<void(const KFileItemList &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'slotOpenUrlRequest'
        QtMocHelpers::SlotData<void(const QUrl &, const KParts::OpenUrlArguments &)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotOpenUrlRequest'
        QtMocHelpers::SlotData<void(const QUrl &)>(50, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotEmitOpenUrlRequestDelayed'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnableAction'
        QtMocHelpers::SlotData<void(const char *, bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotSetActionText'
        QtMocHelpers::SlotData<void(const char *, const QString &)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'urlDropHandling'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NavigationExtension, qt_meta_tag_ZN6KParts19NavigationExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KParts::NavigationExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts19NavigationExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts19NavigationExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KParts19NavigationExtensionE_t>.metaTypes,
    nullptr
} };

void KParts::NavigationExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NavigationExtension *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enableAction((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->setActionText((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->openUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 3: _t->openUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->openUrlRequestDelayed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 5: _t->openUrlNotify(); break;
        case 6: _t->setLocationBarUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->setIconUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->createNewWindow((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->loadingProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->speedProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->infoMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[5]))); break;
        case 13: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[4]))); break;
        case 14: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[3]))); break;
        case 15: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2]))); break;
        case 16: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::ActionGroupMap>>(_a[6]))); break;
        case 17: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<KParts::NavigationExtension::PopupFlags>>(_a[5]))); break;
        case 18: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[4]))); break;
        case 19: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<mode_t>>(_a[3]))); break;
        case 20: _t->popupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 21: _t->selectionInfo((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 22: _t->mouseOverInfo((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 23: _t->addWebSideBar((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 24: _t->moveTopLevelWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 25: _t->resizeTopLevelWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 26: _t->requestFocus((*reinterpret_cast<std::add_pointer_t<KParts::ReadOnlyPart*>>(_a[1]))); break;
        case 27: _t->setPageSecurity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->itemsRemoved((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 29: _t->slotOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KParts::OpenUrlArguments>>(_a[2]))); break;
        case 30: _t->slotOpenUrlRequest((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 31: _t->slotEmitOpenUrlRequestDelayed(); break;
        case 32: _t->slotEnableAction((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: _t->slotSetActionText((*reinterpret_cast<std::add_pointer_t<const char*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KParts::ReadOnlyPart* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const char * , bool )>(_a, &NavigationExtension::enableAction, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const char * , const QString & )>(_a, &NavigationExtension::setActionText, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QUrl & , const KParts::OpenUrlArguments & )>(_a, &NavigationExtension::openUrlRequest, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QUrl & , const KParts::OpenUrlArguments & )>(_a, &NavigationExtension::openUrlRequestDelayed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)()>(_a, &NavigationExtension::openUrlNotify, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QString & )>(_a, &NavigationExtension::setLocationBarUrl, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QUrl & )>(_a, &NavigationExtension::setIconUrl, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QUrl & )>(_a, &NavigationExtension::createNewWindow, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(int )>(_a, &NavigationExtension::loadingProgress, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(int )>(_a, &NavigationExtension::speedProgress, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QString & )>(_a, &NavigationExtension::infoMessage, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QPoint & , const KFileItemList & , const KParts::OpenUrlArguments & , KParts::NavigationExtension::PopupFlags , const KParts::NavigationExtension::ActionGroupMap & )>(_a, &NavigationExtension::popupMenu, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QPoint & , const QUrl & , mode_t , const KParts::OpenUrlArguments & , KParts::NavigationExtension::PopupFlags , const KParts::NavigationExtension::ActionGroupMap & )>(_a, &NavigationExtension::popupMenu, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const KFileItemList & )>(_a, &NavigationExtension::selectionInfo, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const KFileItem & )>(_a, &NavigationExtension::mouseOverInfo, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const QUrl & , const QString & )>(_a, &NavigationExtension::addWebSideBar, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(int , int )>(_a, &NavigationExtension::moveTopLevelWidget, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(int , int )>(_a, &NavigationExtension::resizeTopLevelWidget, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(KParts::ReadOnlyPart * )>(_a, &NavigationExtension::requestFocus, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(int )>(_a, &NavigationExtension::setPageSecurity, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (NavigationExtension::*)(const KFileItemList & )>(_a, &NavigationExtension::itemsRemoved, 28))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isURLDropHandlingEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setURLDropHandlingEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KParts::NavigationExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KParts::NavigationExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts19NavigationExtensionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KParts::NavigationExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KParts::NavigationExtension::enableAction(const char * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KParts::NavigationExtension::setActionText(const char * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KParts::NavigationExtension::openUrlRequest(const QUrl & _t1, const KParts::OpenUrlArguments & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 4
void KParts::NavigationExtension::openUrlRequestDelayed(const QUrl & _t1, const KParts::OpenUrlArguments & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KParts::NavigationExtension::openUrlNotify()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KParts::NavigationExtension::setLocationBarUrl(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KParts::NavigationExtension::setIconUrl(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KParts::NavigationExtension::createNewWindow(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KParts::NavigationExtension::loadingProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KParts::NavigationExtension::speedProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void KParts::NavigationExtension::infoMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KParts::NavigationExtension::popupMenu(const QPoint & _t1, const KFileItemList & _t2, const KParts::OpenUrlArguments & _t3, KParts::NavigationExtension::PopupFlags _t4, const KParts::NavigationExtension::ActionGroupMap & _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 16
void KParts::NavigationExtension::popupMenu(const QPoint & _t1, const QUrl & _t2, mode_t _t3, const KParts::OpenUrlArguments & _t4, KParts::NavigationExtension::PopupFlags _t5, const KParts::NavigationExtension::ActionGroupMap & _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}

// SIGNAL 21
void KParts::NavigationExtension::selectionInfo(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void KParts::NavigationExtension::mouseOverInfo(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void KParts::NavigationExtension::addWebSideBar(const QUrl & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}

// SIGNAL 24
void KParts::NavigationExtension::moveTopLevelWidget(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1, _t2);
}

// SIGNAL 25
void KParts::NavigationExtension::resizeTopLevelWidget(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2);
}

// SIGNAL 26
void KParts::NavigationExtension::requestFocus(KParts::ReadOnlyPart * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void KParts::NavigationExtension::setPageSecurity(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void KParts::NavigationExtension::itemsRemoved(const KFileItemList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}
QT_WARNING_POP
