/****************************************************************************
** Meta object code from reading C++ file 'readonlypart.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kparts-6.26.0/src/readonlypart.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'readonlypart.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KParts12ReadOnlyPartE_t {};
} // unnamed namespace

template <> constexpr inline auto KParts::ReadOnlyPart::qt_create_metaobjectdata<qt_meta_tag_ZN6KParts12ReadOnlyPartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KParts::ReadOnlyPart",
        "started",
        "",
        "KIO::Job*",
        "job",
        "completed",
        "completedWithPendingAction",
        "canceled",
        "errMsg",
        "urlChanged",
        "QUrl",
        "url",
        "openUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'started'
        QtMocHelpers::SignalData<void(KIO::Job *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'completedWithPendingAction'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canceled'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'urlChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<bool(const QUrl &)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'url'
        QtMocHelpers::PropertyData<QUrl>(11, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReadOnlyPart, qt_meta_tag_ZN6KParts12ReadOnlyPartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KParts::ReadOnlyPart::staticMetaObject = { {
    QMetaObject::SuperData::link<Part::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts12ReadOnlyPartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts12ReadOnlyPartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KParts12ReadOnlyPartE_t>.metaTypes,
    nullptr
} };

void KParts::ReadOnlyPart::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReadOnlyPart *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->started((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1]))); break;
        case 1: _t->completed(); break;
        case 2: _t->completedWithPendingAction(); break;
        case 3: _t->canceled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->urlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: { bool _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyPart::*)(KIO::Job * )>(_a, &ReadOnlyPart::started, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyPart::*)()>(_a, &ReadOnlyPart::completed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyPart::*)()>(_a, &ReadOnlyPart::completedWithPendingAction, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyPart::*)(const QString & )>(_a, &ReadOnlyPart::canceled, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyPart::*)(const QUrl & )>(_a, &ReadOnlyPart::urlChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->url(); break;
        default: break;
        }
    }
}

const QMetaObject *KParts::ReadOnlyPart::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KParts::ReadOnlyPart::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KParts12ReadOnlyPartE_t>.strings))
        return static_cast<void*>(this);
    return Part::qt_metacast(_clname);
}

int KParts::ReadOnlyPart::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Part::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KParts::ReadOnlyPart::started(KIO::Job * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KParts::ReadOnlyPart::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KParts::ReadOnlyPart::completedWithPendingAction()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KParts::ReadOnlyPart::canceled(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KParts::ReadOnlyPart::urlChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
